import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type TagRef = React.Ref<HTMLDivElement | HTMLButtonElement>;
export declare type TagProps = PropsWithMetadata<{
    /** The text on the tag */
    text: string;
    /** The Tag's background color as hex */
    backgroundColor?: string;
    /** Allows providing a custom class name */
    className?: string;
    /** The Tag's text color as hex */
    color?: string;
    /**
     * Determines whether the tag is interactive.
     *
     * If set to `click`, the tag becomes clickable and clicking on it will trigger `onClick` callback.
     *
     * If set to `remove`, the tab becomes removable and clicking on its remove button will trigger `onRemove` callback.
     *
     * Otherwise, the tag is not interactive and no callback will be triggered.
     */
    interaction?: 'none' | 'click' | 'remove';
    /** The max width of the Tag */
    maxWidth?: number;
    /** The callback to execute when interacting with the tag */
    onClick?: React.MouseEventHandler;
    /** The callback to execute when removing the tag */
    onRemove?: React.MouseEventHandler;
}> & (React.ComponentPropsWithoutRef<'div'> | React.ComponentPropsWithoutRef<'button'>);
export declare function TagWithRef({ text, backgroundColor, className, color, maxWidth, interaction, metadata, onClick, onRemove, }: TagProps, ref: TagRef): React.DetailedReactHTMLElement<{
    className: string;
    ref: TagRef;
    style: {
        backgroundColor: string;
        color: string;
    };
    onClick: (React.MouseEventHandler<Element> & React.MouseEventHandler<HTMLDivElement>) | (React.MouseEventHandler<Element> & React.MouseEventHandler<HTMLButtonElement>) | undefined;
    type: string;
    'data-test-id'?: string | undefined;
    'data-action-name'?: string | undefined;
} | {
    className: string;
    ref: TagRef;
    style: {
        backgroundColor: string;
        color: string;
    };
    onClick?: undefined;
    type?: undefined;
    'data-test-id'?: string | undefined;
    'data-action-name'?: string | undefined;
}, HTMLDivElement | HTMLButtonElement>;
export declare namespace TagWithRef {
    var displayName: string;
}
declare const Tag: React.ForwardRefExoticComponent<TagProps & React.RefAttributes<HTMLDivElement | HTMLButtonElement>>;
export default Tag;
